Changes
=======

0.1.33
------
- register actions with func
- fix setup.py
- bump to edc 0.3.64

0.1.32
------
- Remove a bad validation message on missed visits
- Fix issues with LTFU validation
- Fix issue with saving of the EoS report
- bump to edc 0.3.61

0.1.31
------
- unreleased

0.1.30
------
- decouple from respond-africa

0.1.29
------

0.1.28
------
- add missing migration in mocca_ae

0.1.27
------
- bump edc and respond-africa

0.1.26
------
- default_auto_field
- silence sites.E101 warning in system checks

0.1.25
----------
- remove mocca_register changelist add buttons for screening and refusal when patient
  is deceased.
- add CLINICIAN_SUPER role and group to manage delete perms
- drop FBC form
- drop PHQ-9
- fix issue where lipid result form unable to save
- add CHOL to lipids form
- add cholesterol review form
- update testing for dj3.2, drop py3.7

0.1.17
------
- initial
